@@ -1,7 +1,8 @@
-__version__ = "0.10.2"
+__version__ = "0.12.5"
 
 import os
 import platform
+import configparser
 
 ver = platform.python_version_tuple()
 
@@ -34,9 +35,7 @@ def packagefinder(filename, package, module=None, read_config=False, return_text
         msg = 'ERROR: Could not find module "{}"'.format(module)
         raise PackageFinderException(msg)
 
-    if read_config:
-        return read_package_file(imported, filename)
-    elif return_text:
+    if return_text:
         try:
             return pkg_resources.read_text(imported, filename)
         except FileNotFoundError as e:
@@ -51,7 +50,12 @@ def packagefinder(filename, package, module=None, read_config=False, return_text
             )
             raise PackageFinderException(msg)
 
-        return resource_filepath
+        if read_config:
+            config = configparser.ConfigParser()
+            config.read(resource_filepath)
+            return config
+        else:
+            return resource_filepath
 
 
 class ResourceDict(dict):
@@ -128,5 +132,4 @@ def import_resources(configs, package):
         filename = check_extension(configs)
         return packagefinder(filename, package=package, read_config=True)
 
-
 # -- end
